@@ -1,23 +1,8 @@
-/***************************************************************************
- *   KSystemLog, a system log viewer tool                                  *
- *   Copyright (C) 2007 by Nicolas Ternisien                               *
- *   nicolas.ternisien@gmail.com                                           *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- *   This program is distributed in the hope that it will be useful,       *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the                         *
- *   Free Software Foundation, Inc.,                                       *
- *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.          *
- ***************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2007 Nicolas Ternisien <nicolas.ternisien@gmail.com>
+
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "generalConfigurationWidget.h"
 
@@ -32,7 +17,7 @@
 #include "defaults.h"
 #include "globals.h"
 #include "ksystemlogConfig.h"
-#include "logging.h"
+#include "ksystemlog_debug.h"
 
 GeneralConfigurationWidget::GeneralConfigurationWidget()
     : QWidget()
@@ -57,8 +42,8 @@ GeneralConfigurationWidget::GeneralConfigurationWidget()
 
         startupLogMode->addItem(logMode->icon(), logMode->name(), QVariant(logMode->id()));
     }
-    connect(startupLogMode, QOverload<int>::of(&QComboBox::currentIndexChanged), this, &GeneralConfigurationWidget::configurationChanged);
-    connect(maxLines, QOverload<int>::of(&QSpinBox::valueChanged), this, &GeneralConfigurationWidget::configurationChanged);
+    connect(startupLogMode, &QComboBox::currentIndexChanged, this, &GeneralConfigurationWidget::configurationChanged);
+    connect(maxLines, &QSpinBox::valueChanged, this, &GeneralConfigurationWidget::configurationChanged);
 
     connect(deleteDuplicatedLines, &QAbstractButton::clicked, this, &GeneralConfigurationWidget::configurationChanged);
 
@@ -71,7 +56,7 @@ GeneralConfigurationWidget::GeneralConfigurationWidget()
     mDateFormatGroup->addButton(formatShortDate, Globals::ShortFormat);
     mDateFormatGroup->addButton(formatPreciseDate, Globals::PreciseFormat);
 
-    connect(mDateFormatGroup, QOverload<QAbstractButton *>::of(&QButtonGroup::buttonClicked), this, &GeneralConfigurationWidget::configurationChanged);
+    connect(mDateFormatGroup, &QButtonGroup::buttonClicked, this, &GeneralConfigurationWidget::configurationChanged);
 
     addDateFormatExample();
 }
@@ -115,7 +100,7 @@ void GeneralConfigurationWidget::readConfig()
 
 void GeneralConfigurationWidget::saveConfig() const
 {
-    logDebug() << "Save config from General preferences";
+    qCDebug(KSYSTEMLOG) << "Save config from General preferences";
 
     KSystemLogConfig::setStartupLogMode(startupLogMode->itemData(startupLogMode->currentIndex()).toString());
 
@@ -143,10 +128,10 @@ bool GeneralConfigurationWidget::isValid() const
             LogMode *mode = Globals::instance().findLogMode(modeString);
             if (mode) {
                 if (!mode->filesExist()) {
-                    logDebug() << "Log files are missing for mode" << mode->name();
+                    qCDebug(KSYSTEMLOG) << "Log files are missing for mode" << mode->name();
                     mWarningBox->setVisible(true);
                 } else {
-                    logDebug() << "General configuration is valid";
+                    qCDebug(KSYSTEMLOG) << "General configuration is valid";
                     mWarningBox->setVisible(false);
                     return true;
                 }
@@ -158,6 +143,6 @@ bool GeneralConfigurationWidget::isValid() const
         }
     }
 
-    logDebug() << "General configuration is not valid";
+    qCDebug(KSYSTEMLOG) << "General configuration is not valid";
     return false;
 }
