@@ -1,23 +1,8 @@
-/***************************************************************************
- *   KSystemLog, a system log viewer tool                                  *
- *   Copyright (C) 2007 by Nicolas Ternisien                               *
- *   nicolas.ternisien@gmail.com                                           *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- *   This program is distributed in the hope that it will be useful,       *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the                         *
- *   Free Software Foundation, Inc.,                                       *
- *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.          *
- ***************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2007 Nicolas Ternisien <nicolas.ternisien@gmail.com>
+
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "logViewSearchWidget.h"
 
@@ -31,9 +16,9 @@
 #include <KLocalizedString>
 #include <QIcon>
 
+#include "ksystemlog_debug.h"
 #include "logViewWidget.h"
 #include "logViewWidgetItem.h"
-#include "logging.h"
 
 LogViewSearchWidget::LogViewSearchWidget(QWidget *parent)
     : QWidget(parent)
@@ -110,7 +95,7 @@ void LogViewSearchWidget::findFirst()
 
 void LogViewSearchWidget::findNext()
 {
-    logDebug() << "Finding next";
+    qCDebug(KSYSTEMLOG) << "Finding next";
 
     LogViewWidgetItem *lastSelectedItem = mLogViewWidget->lastSelectedItem();
     internalFind(lastSelectedItem, LogViewSearchWidget::Next);
@@ -118,7 +103,7 @@ void LogViewSearchWidget::findNext()
 
 void LogViewSearchWidget::findPrevious()
 {
-    logDebug() << "Finding previous";
+    qCDebug(KSYSTEMLOG) << "Finding previous";
 
     LogViewWidgetItem *firstSelectedItem = mLogViewWidget->firstSelectedItem();
     internalFind(firstSelectedItem, LogViewSearchWidget::Previous);
@@ -291,7 +276,7 @@ void LogViewSearchWidget::highlightAll()
     if (highlightAllButton->isChecked()) {
         unlightAll();
 
-        logDebug() << "Highlighting all";
+        qCDebug(KSYSTEMLOG) << "Highlighting all";
         QTreeWidgetItemIterator it(mLogViewWidget, QTreeWidgetItemIterator::All);
         while (*it) {
             auto item = static_cast<LogViewWidgetItem *>(*it);
@@ -309,7 +294,7 @@ void LogViewSearchWidget::highlightAll()
 
 void LogViewSearchWidget::unlightAll()
 {
-    logDebug() << "Unlighting all";
+    qCDebug(KSYSTEMLOG) << "Unlighting all";
 
     QTreeWidgetItemIterator it(mLogViewWidget, QTreeWidgetItemIterator::All);
     while (*it) {
