@@ -6,9 +6,6 @@
 
 #pragma once
 
-#include <QGroupBox>
-#include <QHBoxLayout>
-
 #include <KLocalizedString>
 #include <KUrlRequester>
 
@@ -49,4 +46,3 @@ private:
     KUrlRequester *mAuthenticationUrlRequester = nullptr;
     KMessageWidget *mWarningBox = nullptr;
 };
-
